@@ -866,7 +866,7 @@ g_usb_device_set_interface_alt (GUsbDevice *device, gint interface,
 
 /**
  * g_usb_device_get_string_descriptor:
- * @desc_index: the index for the string descriptor to retreive
+ * @desc_index: the index for the string descriptor to retrieve
  * @error: a #GError, or %NULL
  *
  * Get a string descriptor from the device. The returned string should be freed
@@ -932,7 +932,7 @@ g_usb_device_sync_transfer_cb (GUsbDevice     *device,
  * @data: (array length=length): a suitably-sized data buffer for
  * either input or output
  * @length: the length field for the setup packet.
- * @actual_length: the actual number of bytes sent, or %NULL
+ * @actual_length: (out) (optional): the actual number of bytes sent, or %NULL
  * @timeout: timeout timeout (in millseconds) that this function should wait
  * before giving up due to no response being received. For an unlimited
  * timeout, use 0.
@@ -999,7 +999,7 @@ g_usb_device_control_transfer (GUsbDevice            *device,
  * @data: (array length=length): a suitably-sized data buffer for
  * either input or output
  * @length: the length field for the setup packet.
- * @actual_length: the actual number of bytes sent, or %NULL
+ * @actual_length: (out) (optional): the actual number of bytes sent, or %NULL
  * @timeout: timeout timeout (in millseconds) that this function should wait
  * before giving up due to no response being received. For an unlimited
  * timeout, use 0.
@@ -1056,7 +1056,7 @@ g_usb_device_bulk_transfer (GUsbDevice    *device,
  * @data: (array length=length): a suitably-sized data buffer for
  * either input or output
  * @length: the length field for the setup packet.
- * @actual_length: the actual number of bytes sent, or %NULL
+ * @actual_length: (out) (optional): the actual number of bytes sent, or %NULL
  * @timeout: timeout timeout (in millseconds) that this function should wait
  * before giving up due to no response being received. For an unlimited
  * timeout, use 0.
@@ -1550,7 +1550,6 @@ g_usb_device_interrupt_transfer_finish (GUsbDevice    *device,
  * @device: a #GUsbDevice
  *
  * Gets the platform identifier for the device.
- * On Linux, this is the full sysfs path of the device
  *
  * When the device is removed and then replugged, this value is not expected to
  * be different.
@@ -1733,6 +1732,25 @@ g_usb_device_get_release (GUsbDevice *device)
 	return device->priv->desc.bcdDevice;
 }
 
+/**
+ * g_usb_device_get_spec:
+ * @device: a #GUsbDevice
+ *
+ * Gets the BCD specification revision for the device. For example,
+ * `0x0110` indicates USB 1.1 and 0x0320 indicates USB 3.2
+ *
+ * Return value: a specification revision in BCD format.
+ *
+ * Since: 0.3.1
+ **/
+guint16
+g_usb_device_get_spec (GUsbDevice *device)
+{
+	g_return_val_if_fail (G_USB_IS_DEVICE (device), 0);
+
+	return device->priv->desc.bcdUSB;
+}
+
 /**
  * g_usb_device_get_vid_as_str:
  * @device: a #GUsbDevice
